AlekSIS (School Information System) — App for CSV imports
====================================================================

AlekSIS
-------

This is an application for use with the `AlekSIS®`_ platform.

Features
--------

This app provides general CSV imports functions to interact with school administration software.

* Generic and customisable importer based on templates
* Register import templates in the frontend

Supported systems:

* Schild-NRW (North Rhine-Westphalia, Germany)
* Pedasos (Schleswig-Holstein, Germany

Licence
-------

::

  Copyright © 2019, 2020, 2022 Dominik George <dominik.george@teckids.org>
  Copyright © 2020, 2021 Jonathan Weth <dev@jonathanweth.de>
  Copyright © 2019 mirabilos <thorsten.glaser@teckids.org>
  Copyright © 2019 Tom Teichler <tom.teichler@teckids.org>

  Licenced under the EUPL, version 1.2 or later, by Teckids e.V. (Bonn, Germany).

Please see the LICENCE.rst file accompanying this distribution for the
full licence text or on the `European Union Public Licence`_ website
https://joinup.ec.europa.eu/collection/eupl/guidelines-users-and-developers
(including all other official language versions).

Trademark
---------

AlekSIS® is a registered trademark of the AlekSIS open source project, represented
by Teckids e.V. Please refer to the `trademark policy`_ for hints on using the trademark
AlekSIS®.

.. _AlekSIS®: https://edugit.org/AlekSIS/AlekSIS
.. _European Union Public Licence: https://eupl.eu/
.. _trademark policy: https://aleksis.org/pages/about
